@@ -13,7 +13,6 @@ from omas import *
 ods = load_omas_s3('OMFITprofiles_sample', user='omas_shared')
 
 # augment ODS with pressure information
-ods.consistency_check = False  # NOTE: some extra pressures are calculated if IMAS consistency_check = False
 ods.physics_core_profiles_pressures()
 
 # omas plot for pressures
@@ -27,3 +26,8 @@ pyplot.show()
 # omas plot for equilibrium
 omas_plot.equilibrium_summary(ods, linewidth=1, label='my equilibrium')
 pyplot.show()
+
+# omas plot for transport fluxes
+ods = ODS().sample(5)
+ods.plot_core_transport_fluxes()
+pyplot.show()
