@@ -345,15 +345,6 @@ def pf_active(ods, nc_weird=0, nc_undefined=0):
     return ods
 
 
-@add_to_ODS
-def ec_launchers(ods):
-    from omas import load_omas_json
-
-    pr = load_omas_json(os.path.join('omas', 'samples', 'd3d_ECRH_machine_mapping.json'))['ec_launchers']
-    ods['ec_launchers'].update(pr)
-    return ods
-
-
 @add_to_ODS
 def magnetics(ods):
     """
@@ -753,14 +744,17 @@ def ec_launchers(ods, ngyros=2, ntimes=6):
     ods['ec_launchers.ids_properties.homogeneous_time'] = 1
     for gyro in range(ngyros):
         ods['ec_launchers']['time'] = times
+        ods['ec_launchers']['beam'][gyro]['time'] = times
         ods['ec_launchers']['beam'][gyro]['identifier'] = 'GYRO_' + str(gyro)
         ods['ec_launchers']['beam'][gyro]['frequency']['data'] = ones * 110e9
+        ods['ec_launchers']['beam'][gyro]['frequency']['time'] = times
 
         ods['ec_launchers']['beam'][gyro]['launching_position']['phi'] = 0.0 * ones
         ods['ec_launchers']['beam'][gyro]['launching_position']['r'] = 2.4 * ones
         ods['ec_launchers']['beam'][gyro]['launching_position']['z'] = 0.68 * ones
         ods['ec_launchers']['beam'][gyro]['mode'] = -1
         ods['ec_launchers']['beam'][gyro]['power_launched']['data'] = 0.5e6 * (ones - 0.5 * numpy.cos(2 * numpy.pi * times + gyro / ngyros))
+        ods['ec_launchers']['beam'][gyro]['power_launched']['time'] = times
 
         ods['ec_launchers']['beam'][gyro]['steering_angle_pol'] = 0.61 * ones
         ods['ec_launchers']['beam'][gyro]['steering_angle_tor'] = 0.0 * ones
@@ -791,7 +785,9 @@ def nbi(ods, nunits=2, ntimes=6):
 
     for unit in range(nunits):
         ods['nbi']['unit'][unit]['beam_current_fraction']['data'] = [0.27032773 * ones, 0.14438479 * ones, 0.07613747 * ones]
+        ods['nbi']['unit'][unit]['beam_current_fraction']['time'] = times
         ods['nbi']['unit'][unit]['beam_power_fraction']['data'] = [0.36067036 * ones, 0.09631886 * ones, 0.03386079 * ones]
+        ods['nbi']['unit'][unit]['beam_power_fraction']['time'] = times
         ods['nbi']['unit'][unit]['beamlets_group'][0]['angle'] = -0
         ods['nbi']['unit'][unit]['beamlets_group'][0]['direction'] = 1
 
@@ -809,8 +805,10 @@ def nbi(ods, nunits=2, ntimes=6):
 
         ods['nbi']['unit'][unit]['identifier'] = 'beam_' + str(unit)
         ods['nbi']['unit'][unit]['energy']['data'] = 80e3 * ones
+        ods['nbi']['unit'][unit]['energy']['time'] = times
 
         ods['nbi']['unit'][unit]['power_launched']['data'] = 2.0e6 * (ones - 0.5 * numpy.cos(2 * numpy.pi * times + unit / nunits))
+        ods['nbi']['unit'][unit]['power_launched']['time'] = times
 
         ods['nbi']['unit'][unit]['species']['a'] = 2.0
         ods['nbi']['unit'][unit]['species']['z_n'] = 1.0
