@@ -171,7 +171,7 @@ omas_rcparams.update(
         ),
         'allow_fake_imas_fallback': bool(int(os.environ.get('OMAS_ALLOW_FAKE_IMAS_FALLBACK', '0'))),
         'default_imas_version': _default_imas_version,
-        'default_mongo_server': 'mongodb+srv://{user}:{pass}@omasdb-xymmt.mongodb.net',
+        'default_mongo_server': 'mongodb+srv://{user}:{pass}@omasdb.xymmt.mongodb.net',
         'pickle_protocol': 4,
     }
 )
